from setuptools import setup
from pundit import __version__

setup(name='pundit',
      version=__version__,
      description="ITTT for python",
      url='https://github.com/sachinvettithanam/pundit',
      author=['Anoop Thomas Mathew','Sachin Philip Mathew'],
      author_email='me@imsach.in',
      keywords='rule engine',
      license='MIT',
      packages=['pundit'],
      zip_safe=False,
      )
